@@ -1,5 +1,7 @@
 import pytest
-import rapidjson
+
+import rapidjson as rj
+
 
 # from http://json.org/JSON_checker/test/pass2.json
 JSON = r'''
@@ -9,6 +11,6 @@ JSON = r'''
 @pytest.mark.unit
 def test_parse():
     # test in/out equivalence and parsing
-    res = rapidjson.loads(JSON)
-    out = rapidjson.dumps(res)
-    assert res == rapidjson.loads(out)
+    res = rj.loads(JSON)
+    out = rj.dumps(res)
+    assert res == rj.loads(out)
